import { default as React, MutableRefObject } from 'react';

/**
 * Suggestions preselected options navigation configuration.
 */
export interface SuggestionsNavigation {
    /**
     * Return true if the preselected options navigation is initialized.
     */
    initialized(): boolean;
    /**
     * Preselect the next option in the suggestions.
     */
    next(): void;
    /**
     * Preselect the previous option in the suggestions.
     */
    previous(): void;
    /**
     * Select the currently preselected option.
     */
    select(): void;
}
/**
 * Hook to get the preselected options navigation reference.
 */
export declare function useSuggestionsNavigation(): MutableRefObject<SuggestionsNavigation>;
export declare function OptionsSuggestions<OptionKey extends keyof any, Option>({ options, onSelected, selectedOptions, renderOption, navigator }: {
    /**
     * Options to suggest.
     */
    options: Record<OptionKey, Option>;
    /**
     * Called when an option is selected.
     * @param key
     * @param option
     */
    onSelected: (key: OptionKey, option: Option) => void;
    /**
     * Already selected options that will be shown differently.
     */
    selectedOptions?: Record<OptionKey, Option>;
    /**
     * Render an option.
     * @param option The option to render.
     */
    renderOption?: (option: Option) => React.ReactNode;
    /**
     * A reference to a preselected suggestions options navigation object.
     */
    navigator?: MutableRefObject<SuggestionsNavigation>;
}): React.ReactNode;
